==> darcs_2.14.5.orig.tar.gz: darcs-2.14.5/tests/issue2271-disable-patch-index.sh <==
#!/usr/bin/env bash
## Test for issue2271 - --disable-patch-index should really work
##
## Copyright (C) 2013 Mark Stosberg
##
## Permission is hereby granted, free of charge, to any person
## obtaining a copy of this software and associated documentation
## files (the "Software"), to deal in the Software without
## restriction, including without limitation the rights to use, copy,
## modify, merge, publish, distribute, sublicense, and/or sell copies
## of the Software, and to permit persons to whom the Software is
## furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be
## included in all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
## EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
## MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
## NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
## BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
## ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
## CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
## SOFTWARE.

. lib                           # Load some portability helpers.

darcs init      --repo R        # Create our test repos.
cd R
touch t.txt
darcs add t.txt
darcs record -am 'initial record' t.txt
darcs optimize enable-patch-index

chmod -w _darcs/patch_index

not darcs optimize disable-patch-index 2>&1 | grep 'Could not delete patch index'

cd ../

==> darcs_2.18.4.orig.tar.gz: darcs-2.18.4/tests/issue2271-disable-patch-index.sh <==
#!/usr/bin/env bash
## Test for issue2271 - --disable-patch-index should really work
##
## Copyright (C) 2013 Mark Stosberg
##
## Permission is hereby granted, free of charge, to any person
## obtaining a copy of this software and associated documentation
## files (the "Software"), to deal in the Software without
## restriction, including without limitation the rights to use, copy,
## modify, merge, publish, distribute, sublicense, and/or sell copies
## of the Software, and to permit persons to whom the Software is
## furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be
## included in all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
## EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
## MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
## NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
## BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
## ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
## CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
## SOFTWARE.

. lib                           # Load some portability helpers.

rm -rf R
darcs init      --repo R        # Create our test repos.

trap "chmod +w $PWD/R/_darcs/patch_index" EXIT

cd R
touch t.txt
darcs add t.txt
darcs record -am 'initial record' t.txt
darcs optimize enable-patch-index

chmod -w _darcs/patch_index

not darcs optimize disable-patch-index 2>&1 | tee LOG
grep 'Could not delete patch index' LOG

# cleanup
cd ../
